@@ -43,6 +43,7 @@ def cache_to_django(
                     cache_conf,
                 )
             )
+            print('to completed:', to_complete)
             completed += 1
             if len(async_tasks) == async_chunk_size or completed == to_complete:
                 await asyncio.gather(*async_tasks)
@@ -110,7 +111,6 @@ async def update_or_create_django_instance_from_redis_instance(
     for k, v in django_params.items():
         if k not in ['django_id', 'id']:
             new_django_params[k] = v
-    print(new_django_params)
     django_params = new_django_params
     django_instance = await sync_to_async_update_or_create_django_instance_from_redis_instance(
         redis_root,
@@ -137,9 +137,11 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
 ):
     need_to_create = True
     if django_id not in ['null', None]:
+        print(django_id)
+        print(django_model.objects.filter(id=django_id))
         if django_model.objects.filter(id=django_id):
             need_to_create = False
-
+    print(need_to_create)
     django_instance = None
 
     if need_to_create:
@@ -151,6 +153,7 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
                 django_many_to_many_params
             )
             redis_root.delete(django_model, redis_instance)
+            print('cache - created and deleted', django_model, django_instance.id, redis_instance['django_id'])
         else:
             print(f'\n'
                   f'{datetime.datetime.now()} - '
@@ -182,6 +185,7 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
                 changed_many_to_many_fields_to_update[redis_field_name] = redis_field_value
         if cache_conf['write_to_django']:
             django_model.objects.filter(id=django_id).update(**changed_fields_to_update)
+            print('updated', django_id)
             update_django_many_to_many(
                 django_model,
                 django_id,
@@ -197,6 +201,9 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
                   f'and many to many params\n'
                   f'{changed_many_to_many_fields_to_update}'
                   f'\n')
+    print(f'now django {django_model.__name__}: {len(django_model.objects.all())}\n'
+          f'now redis {django_model.__name__}: {len(redis_root.get(django_model))}'
+          '\n\n\n')
     return django_instance
 
 
@@ -216,15 +223,14 @@ async def async_redis_dict_to_django_params(
             if django_field_data['class'] == django_models.ForeignKey:
                 foreign_key_model = django_field_data['remote_field_model']
                 redis_foreign_key_instance = redis_dict[django_field_name]
-                print(redis_foreign_key_instance)
                 if redis_foreign_key_instance not in ['null', None]:
+                    print('cache - creating new instance foreign', django_field, redis_foreign_key_instance)
                     django_foreign_key_instance = await update_or_create_django_instance_from_redis_instance(
                         redis_root,
                         redis_foreign_key_instance,
                         foreign_key_model,
                         cache_conf,
                     )
-                    print(django_foreign_key_instance)
                     django_params[django_field_name] = django_foreign_key_instance
                 else:
                     django_params[django_field_name] = None
@@ -233,6 +239,7 @@ async def async_redis_dict_to_django_params(
                 django_many_to_many_instances = []
                 redis_many_to_many_instances = redis_dict[django_field_data['name']]
                 if redis_many_to_many_instances not in ['null', None] and redis_many_to_many_instances:
+                    print('cache - creating new instance m2m', django_field, django_model)
                     for redis_many_to_many_instance in redis_many_to_many_instances:
                         django_many_to_many_instance = await update_or_create_django_instance_from_redis_instance(
                             redis_root,
