@@ -8,17 +8,23 @@ class RedisQuerySet(django_models.query.QuerySet):
 
     def update(self, **kwargs):
         update_result = super().update(**kwargs)
-        concrete_model = self.model._meta.concrete_model
-        print('update', concrete_model, concrete_model.id)
+        concrete_model = self.model
         redis_root = get_redis_root()
-        data_to_update = redis_root.get(self.model, django_id=concrete_model.id)
+        id = concrete_model.id
+        print('\nRedisQuerySet update:')
+        print('update', concrete_model, self)
+        django_ids_to_update = [django_instance.id for django_instance in self]
+        data_to_update = redis_root.get(self.model, django_id__in=django_ids_to_update)
+        print(f'now data to update {self.model:', len(data_to_update))
         redis_root.update(self.model, data_to_update, **kwargs)
+        print(f'now redis {self.model}:', redis_root.get(self.model))
         return self
 
     def create(self, **kwargs):
         create_result = super().create(**kwargs)
         concrete_model = self.model._meta.concrete_model
-        print('create', concrete_model, create_result.id)
+        create_result = create_result
+        id = create_result.id
         existing_fields = {}
         redis_root = get_redis_root()
         for field in create_result.__class__._meta.get_fields():
@@ -70,7 +76,6 @@ def django_instance_field_to_redis_value(
     redis_value = django_field_value
     if isinstance(django_field_value, DeferredAttribute):
         django_field_value = django_field_value.__get__()
-        print('un deffered django_field_value')
     if django_field.__class__ == django_models.ForeignKey:
         if django_field_value is None:
             redis_value = None
@@ -78,6 +83,7 @@ def django_instance_field_to_redis_value(
             django_foreign_key_instance = django_field_value
             if save_related_models:
                 if django_foreign_key_instance:
+                    print('creating new instance foreign', django_field, django_foreign_key_instance)
                     django_instance_model = django_foreign_key_instance.__class__
                     redis_foreign_key_instance = get_or_create_redis_instance_from_django_instance(
                         redis_root,
@@ -94,6 +100,7 @@ def django_instance_field_to_redis_value(
         if save_related_models:
             if len(django_many_to_many_instances):
                 django_instance_model = django_many_to_many_instances[0].__class__
+                print('creating new instance m2m', django_field, django_instance_model)
                 redis_value = [
                     get_or_create_redis_instance_from_django_instance(
                         redis_root,
